@@ -38,12 +38,21 @@ class CausalEstimator:
 
     DEFAULT_INTERPRET_METHOD = ["textual_effect_interpreter"]
 
+    # std args to be removed from locals() before being passed to args_dict
+    _STD_INIT_ARGS = ('self', '__class__', 'args', 'kwargs')
+
     def __init__(self, data, identified_estimand, treatment, outcome,
                  control_value=0, treatment_value=1,
                  test_significance=False, evaluate_effect_strength=False,
                  confidence_intervals=False,
                  target_units=None, effect_modifiers=None,
-                 params=None):
+                 num_null_simulations=DEFAULT_NUMBER_OF_SIMULATIONS_STAT_TEST,
+                 num_simulations=DEFAULT_NUMBER_OF_SIMULATIONS_CI,
+                 sample_size_fraction=DEFAULT_SAMPLE_SIZE_FRACTION,
+                 confidence_level=DEFAULT_CONFIDENCE_LEVEL,
+                 need_conditional_estimates='auto',
+                 num_quantiles_to_discretize_cont_cols=NUM_QUANTILES_TO_DISCRETIZE_CONT_COLS,
+                 **kwargs):
         """Initializes an estimator with data and names of relevant variables.
 
         This method is called from the constructors of its child classes.
@@ -55,19 +64,29 @@ class CausalEstimator:
         :param outcome: name of the outcome variable
         :param control_value: Value of the treatment in the control group, for effect estimation.  If treatment is multi-variate, this can be a list.
         :param treatment_value: Value of the treatment in the treated group, for effect estimation. If treatment is multi-variate, this can be a list.
-        :param test_significance: Binary flag or a string indicating whether to test significance and by which method. All estimators support test_significance="bootstrap" that estimates a p-value for the obtained estimate using the bootstrap method. Individual estimators can override this to support custom testing methods. The bootstrap method supports an optional parameter, num_null_simulations that can be specified through the params dictionary. If False, no testing is done. If True, significance of the estimate is tested using the custom method if available, otherwise by bootstrap.
+        :param test_significance: Binary flag or a string indicating whether to test significance and by which method. All estimators support test_significance="bootstrap" that estimates a p-value for the obtained estimate using the bootstrap method. Individual estimators can override this to support custom testing methods. The bootstrap method supports an optional parameter, num_null_simulations. If False, no testing is done. If True, significance of the estimate is tested using the custom method if available, otherwise by bootstrap.
         :param evaluate_effect_strength: (Experimental) whether to evaluate the strength of effect
         :param confidence_intervals: Binary flag or a string indicating whether the confidence intervals should be computed and which method should be used. All methods support estimation of confidence intervals using the bootstrap method by using the parameter confidence_intervals="bootstrap". The bootstrap method takes in two arguments (num_simulations and sample_size_fraction) that can be optionally specified in the params dictionary. Estimators may also override this to implement their own confidence interval method. If this parameter is False, no confidence intervals are computed. If True, confidence intervals are computed by the estimator's specific method if available, otherwise through bootstrap.
         :param target_units: The units for which the treatment effect should be estimated. This can be a string for common specifications of target units (namely, "ate", "att" and "atc"). It can also be a lambda function that can be used as an index for the data (pandas DataFrame). Alternatively, it can be a new DataFrame that contains values of the effect_modifiers and effect will be estimated only for this new data.
-        :param effect_modifiers: Variables on which to compute separate effects, or return a heterogeneous effect function. Not all methods support this currently.
-        :param params: (optional) Additional method parameters
-            num_null_simulations: The number of simulations for testing the statistical significance of the estimator
-            num_simulations: The number of simulations for finding the confidence interval (and/or standard error) for a estimate
-            sample_size_fraction: The size of the sample for the bootstrap estimator
-            confidence_level: The confidence level of the confidence interval estimate
-            num_quantiles_to_discretize_cont_cols: The number of quantiles into which a numeric effect modifier is split, to enable estimation of conditional treatment effect over it.
+        :param effect_modifiers: Variables on which to compute separate
+            effects, or return a heterogeneous effect function. Not all
+            methods support this currently.
+        :param num_null_simulations: The number of simulations for testing the
+            statistical significance of the estimator
+        :param num_simulations: The number of simulations for finding the
+            confidence interval (and/or standard error) for a estimate
+        :param sample_size_fraction: The size of the sample for the bootstrap
+            estimator
+        :param confidence_level: The confidence level of the confidence
+            interval estimate
+        :param need_conditional_estimates: Boolean flag indicating whether
+            conditional estimates should be computed. Defaults to True if
+            there are effect modifiers in the graph
+        :param num_quantiles_to_discretize_cont_cols: The number of quantiles
+            into which a numeric effect modifier is split, to enable
+            estimation of conditional treatment effect over it.
+        :param kwargs: (optional) Additional estimator-specific parameters
         :returns: an instance of the estimator class.
-
         """
         self._data = data
         self._target_estimand = identified_estimand
@@ -84,14 +103,9 @@ class CausalEstimator:
         self._bootstrap_estimates = None  # for confidence intervals and std error
         self._bootstrap_null_estimates = None  # for significance test
         self._effect_modifiers = None
-        self.method_params = params
-
+        self.method_params = kwargs
         # Setting the default interpret method
         self.interpret_method = CausalEstimator.DEFAULT_INTERPRET_METHOD
-        # Unpacking the keyword arguments
-        if params is not None:
-            for key, value in params.items():
-                setattr(self, key, value)
 
         self.logger = logging.getLogger(__name__)
 
@@ -114,20 +128,17 @@ class CausalEstimator:
             else:
                 self._effect_modifier_names = None
 
-        # Checking if some parameters were set, otherwise setting to default values
-        if not hasattr(self, 'num_null_simulations'):
-            self.num_null_simulations = CausalEstimator.DEFAULT_NUMBER_OF_SIMULATIONS_STAT_TEST
-        if not hasattr(self, 'num_simulations'):
-            self.num_simulations = CausalEstimator.DEFAULT_NUMBER_OF_SIMULATIONS_CI
-        if not hasattr(self, 'sample_size_fraction'):
-            self.sample_size_fraction = CausalEstimator.DEFAULT_SAMPLE_SIZE_FRACTION
-        if not hasattr(self, 'confidence_level'):
-            self.confidence_level = CausalEstimator.DEFAULT_CONFIDENCE_LEVEL
-        if not hasattr(self, 'num_quantiles_to_discretize_cont_cols'):
-            self.num_quantiles_to_discretize_cont_cols = CausalEstimator.NUM_QUANTILES_TO_DISCRETIZE_CONT_COLS
+        # Check if some parameters were set, otherwise set to default values
+        self.num_null_simulations = num_null_simulations
+        self.num_simulations = num_simulations
+        self.sample_size_fraction = sample_size_fraction
+        self.confidence_level = confidence_level
+        self.num_quantiles_to_discretize_cont_cols = \
+            num_quantiles_to_discretize_cont_cols
         # Estimate conditional estimates by default
-        if not hasattr(self, 'need_conditional_estimates'):
-            self.need_conditional_estimates = bool(self._effect_modifier_names)
+        self.need_conditional_estimates = need_conditional_estimates \
+            if need_conditional_estimates != 'auto' \
+            else bool(self._effect_modifier_names)
 
     @staticmethod
     def get_estimator_object(new_data, identified_estimand, estimate):
@@ -136,12 +147,12 @@ class CausalEstimator:
         Creates a new object with new_data and the identified_estimand
 
         :param new_data: np.ndarray, pd.Series, pd.DataFrame
-        The newly assigned data on which the estimator should run
+            The newly assigned data on which the estimator should run
         :param identified_estimand: IdentifiedEstimand
-        An instance of the identified estimand class that provides the information with
-        respect to which causal pathways are employed when the treatment effects the outcome
+            An instance of the identified estimand class that provides the information with
+            respect to which causal pathways are employed when the treatment effects the outcome
         :param estimate: CausalEstimate
-        It is an already existing estimate whose properties we wish to replicate
+            It is an already existing estimate whose properties we wish to replicate
 
         :returns: An instance of the same estimator class that had generated the given estimate.
         """
@@ -158,7 +169,7 @@ class CausalEstimator:
             confidence_intervals=estimate.params["confidence_intervals"],
             target_units=estimate.params["target_units"],
             effect_modifiers=estimate.params["effect_modifiers"],
-            params=estimate.params["method_params"]
+            **estimate.params["method_params"]
         )
 
         return new_estimator
@@ -297,7 +308,6 @@ class CausalEstimator:
         # Perform the set number of simulations
         for index in range(num_bootstrap_simulations):
             new_data = resample(self._data, n_samples=sample_size)
-
             new_estimator = type(self)(
                 new_data,
                 self._target_estimand,
@@ -310,7 +320,7 @@ class CausalEstimator:
                 confidence_intervals=False,
                 target_units=self._target_units,
                 effect_modifiers=self._effect_modifier_names,
-                params=self.method_params
+                **self.method_params
             )
             new_effect = new_estimator.estimate_effect()
             simulation_results[index] = new_effect.value
@@ -504,7 +514,7 @@ class CausalEstimator:
                     confidence_intervals=False,
                     target_units=self._target_units,
                     effect_modifiers=self._effect_modifier_names,
-                    params=self.method_params
+                    **self.method_params
                 )
                 new_effect = new_estimator.estimate_effect()
                 null_estimates[i] = new_effect.value
