@@ -6,26 +6,37 @@ from dowhy.causal_estimator import CausalEstimate
 from dowhy.causal_estimators.propensity_score_estimator import PropensityScoreEstimator
 
 class PropensityScoreMatchingEstimator(PropensityScoreEstimator):
-    """ Estimate effect of treatment by finding matching treated and control units based on propensity score.
+    """ Estimate effect of treatment by finding matching treated and control
+    units based on propensity score.
 
     Straightforward application of the back-door criterion.
 
-    Supports additional parameters that can be specified in the estimate_effect() method.
+    For a list of standard args and kwargs, see documentation for
+    :class:`~dowhy.causal_estimator.CausalEstimator`.
 
-    - 'propensity_score_model': The model used to compute propensity score. Could be any classification model that supports fit() and predict_proba() methods. If None, use LogisticRegression model as the default. Default=None
-    - 'recalculate_propensity_score': If true, force the estimator to calculate the propensity score. To use pre-computed propensity score, set this value to false. Default=True
-    - 'propensity_score_column': column name that stores the propensity score. Default='propensity_score'
+    Supports additional parameters as listed below.
 
     """
     def __init__(
-        self, 
-        *args, 
-        propensity_score_model=None, 
-        recalculate_propensity_score=True, 
+        self,
+        *args,
+        propensity_score_model=None,
+        recalculate_propensity_score=True,
         propensity_score_column="propensity_score",
         **kwargs):
+        """
+        :param propensity_score_model: Model used to compute propensity score.
+            Can be any classification model that supports fit() and
+            predict_proba() methods. If None, LogisticRegression is used.
+        :param recalculate_propensity_score: Whether the propensity score
+            should be estimated. To use pre-computed propensity scores,
+            set this value to False. Default=True.
+        :param propensity_score_column: Column name that stores the
+            propensity score. Default='propensity_score'
+
+        """
         super().__init__(
-            *args, 
+            *args,
             propensity_score_model=propensity_score_model,
             recalculate_propensity_score=recalculate_propensity_score,
             propensity_score_column=propensity_score_column,
@@ -36,18 +47,7 @@ class PropensityScoreMatchingEstimator(PropensityScoreEstimator):
         self.logger.info(self.symbolic_estimator)
 
     def _estimate_effect(self):
-        if self.recalculate_propensity_score is True:
-            if self.propensity_score_model is None:
-                self.propensity_score_model = linear_model.LogisticRegression()
-            self.propensity_score_model.fit(self._observed_common_causes, self._treatment)
-            self._data[self.propensity_score_column] = self.propensity_score_model.predict_proba(self._observed_common_causes)[:, 1]
-        else:
-            # check if the user provides a propensity score column
-            if self.propensity_score_column not in self._data.columns:
-                raise ValueError(f"Propensity score column {self.propensity_score_column} does not exist. Please specify the column name that has your pre-computed propensity score.")
-            else:
-                self.logger.info(f"INFO: Using pre-computed propensity score in column {self.propensity_score_column}")
-
+        self._refresh_propensity_score()
 
         # this assumes a binary treatment regime
         treated = self._data.loc[self._data[self._treatment_name[0]] == 1]
