@@ -1,6 +1,6 @@
 import numpy as np
 import pandas as pd
-from sklearn import linear_model
+
 
 from dowhy.causal_estimator import CausalEstimate
 from dowhy.causal_estimators.propensity_score_estimator import PropensityScoreEstimator
@@ -12,58 +12,67 @@ class PropensityScoreWeightingEstimator(PropensityScoreEstimator):
 
     Straightforward application of the back-door criterion.
 
-    Supports additional parameters that can be specified in the estimate_effect() method.
+    For a list of standard args and kwargs, see documentation for
+    :class:`~dowhy.causal_estimator.CausalEstimator`.
 
-    - 'min_ps_score': Lower bound used to clip the propensity score. Default=0.05
-    - 'max_ps_score': Upper bound used to clip the propensity score. Default=0.95
-    - 'weighting_scheme': This is the name of weighting method to use. Can be inverse propensity score ("ips_weight", default), stabilized IPS score ("ips_stabilized_weight"), or normalized IPS score ("ips_normalized_weight")
-    - 'propensity_score_model': The model used to compute propensity score. Could be any classification model that supports fit() and predict_proba() methods. If None, use LogisticRegression model as the default. Default=None
-    - 'recalculate_propensity_score': If true, force the estimator to calculate the propensity score. To use pre-computed propensity score, set this value to false. Default=True
-    - 'propensity_score_column': column name that stores the propensity score. Default='propensity_score'
+    Supports additional parameters as listed below.
 
     """
-
     def __init__(
-        self, 
-        *args, 
-        min_ps_score=0.05, 
-        max_ps_score=0.95, 
-        weighting_scheme='ips_weight', 
-        propensity_score_model=None, 
-        recalculate_propensity_score=True, 
+        self,
+        *args,
+        min_ps_score=0.05,
+        max_ps_score=0.95,
+        weighting_scheme='ips_weight',
+        propensity_score_model=None,
+        recalculate_propensity_score=True,
         propensity_score_column="propensity_score",
         **kwargs):
+        """
+        :param min_ps_score: Lower bound used to clip the propensity score.
+            Default=0.05
+        :param max_ps_score: Upper bound used to clip the propensity score.
+            Default=0.95
+        :param weighting_scheme: Weighting method to use. Can be inverse
+            propensity score ("ips_weight", default), stabilized IPS score
+            ("ips_stabilized_weight"), or normalized IPS score
+            ("ips_normalized_weight").
+        :param propensity_score_model: The model used to compute propensity
+            score. Can be any classification model that supports fit() and
+            predict_proba() methods. If None, use LogisticRegression model as
+            the default. Default=None
+        :param recalculate_propensity_score: If true, force the estimator to
+            estimate the propensity score. To use pre-computed propensity
+            scores, set this value to false. Default=True
+        :param propensity_score_column: Column name that stores the
+            propensity score. Default='propensity_score'
+        """
+        # Required to ensure that self.method_params contains all the information
+        # to create an object of this class
+        args_dict = kwargs
+        args_dict.update({
+            'min_ps_score': min_ps_score,
+            'max_ps_score': max_ps_score,
+            'weighting_scheme': weighting_scheme
+            })
         super().__init__(
-            *args, 
+            *args,
             propensity_score_model=propensity_score_model,
             recalculate_propensity_score=recalculate_propensity_score,
             propensity_score_column=propensity_score_column,
-            **kwargs)
+            **args_dict)
 
         self.logger.info("INFO: Using Propensity Score Weighting Estimator")
         self.symbolic_estimator = self.construct_symbolic_estimator(
             self._target_estimand)
         self.logger.info(self.symbolic_estimator)
-        if not hasattr(self, "weighting_scheme"):
-            # 'ips_weight', 'ips_normalized_weight', 'ips_stabilized_weight'
-            self.weighting_scheme = weighting_scheme
-        if not hasattr(self, "min_ps_score"):
-            self.min_ps_score = min_ps_score
-        if not hasattr(self, "max_ps_score"):
-            self.max_ps_score = max_ps_score
+        # Setting method specific parameters
+        self.weighting_scheme = weighting_scheme
+        self.min_ps_score = min_ps_score
+        self.max_ps_score = max_ps_score
 
     def _estimate_effect(self):
-        if self.recalculate_propensity_score is True:
-            if self.propensity_score_model is None:
-                self.propensity_score_model = linear_model.LogisticRegression()
-            self.propensity_score_model.fit(self._observed_common_causes, self._treatment)
-            self._data[self.propensity_score_column] = self.propensity_score_model.predict_proba(self._observed_common_causes)[:, 1]
-        else:
-            # check if user provides the propensity score column
-            if self.propensity_score_column not in self._data.columns:
-                raise ValueError(f"Propensity score column {self.propensity_score_column} does not exist. Please specify the column name that has your pre-computed propensity score.")
-            else:
-                self.logger.info(f"INFO: Using pre-computed propensity score in column {self.propensity_score_column}")
+        self._refresh_propensity_score()
 
         # trim propensity score weights
         self._data[self.propensity_score_column] = np.minimum(self.max_ps_score, self._data[self.propensity_score_column])
