@@ -1,10 +1,9 @@
 import itertools
 import logging
 import re
-
 import networkx as nx
-
 from dowhy.utils.api import parse_state
+from dowhy.utils.graph_operations import daggity_to_dot
 
 
 class CausalGraph:
@@ -33,6 +32,19 @@ class CausalGraph:
         mediator_names = parse_state(mediator_names)
         self.logger = logging.getLogger(__name__)
 
+        #re.sub only takes string parameter so the first if is to avoid error
+        #if the input is a text file, convert the contained data into string
+        if isinstance(graph, str) and re.match(r".*\.txt" , str(graph)): 
+            text_file = open(graph , "r")
+            graph = text_file.read()
+            text_file.close()
+ 
+        if isinstance(graph, str) and re.match(r"^dag", graph):   #Convert daggity output to dot format 
+            graph = daggity_to_dot(graph)
+
+        if isinstance(graph, str):
+            graph=graph.replace("\n", " ")
+
         if graph is None:
             self._graph = nx.DiGraph()
             self._graph = self.build_graph(common_cause_names,
