@@ -4,7 +4,7 @@
 import logging
 
 from sympy import init_printing
-
+from itertools import combinations
 import dowhy.graph_learners as graph_learners
 import dowhy.causal_estimators as causal_estimators
 import dowhy.causal_refuters as causal_refuters
@@ -14,6 +14,7 @@ from dowhy.causal_graph import CausalGraph
 from dowhy.causal_identifier import CausalIdentifier
 from dowhy.causal_identifiers.id_identifier import IDIdentifier
 from dowhy.utils.api import parse_state
+from dowhy.causal_refuters.graph_refuter import GraphRefuter
 
 init_printing()  # To display symbolic math symbols
 
@@ -98,8 +99,12 @@ class CausalModel:
                 )
             else:
                 self.logger.warning("Relevant variables to build causal graph not provided. You may want to use the learn_graph() function to construct the causal graph.")
-                self._graph = None
-
+                self._graph = CausalGraph(
+                    self._treatment,
+                    self._outcome,
+                    effect_modifier_names = self._effect_modifiers,
+                    observed_node_names=self._data.columns.tolist()
+                )
         else:
             self.init_graph(graph=graph, identify_vars=identify_vars)
 
@@ -214,7 +219,7 @@ class CausalModel:
             * Instrumental Variables: "iv.instrumental_variable"
             * Regression Discontinuity: "iv.regression_discontinuity"
 
-        In addition, you can directly call any of the EconML estimation methods. The convention is "backdoor.econml.path-to-estimator-class". For example, for the double machine learning estimator ("DML" class) that is located inside "dml" module of EconML, you can use the method name, "backdoor.econml.dml.DML". CausalML estimators can also be called. See `this demo notebook <https://microsoft.github.io/dowhy/example_notebooks/dowhy-conditional-treatment-effects.html>`_.
+        In addition, you can directly call any of the EconML estimation methods. The convention is "backdoor.econml.path-to-estimator-class". For example, for the double machine learning estimator ("DML" class) that is located inside "dml" module of EconML, you can use the method name, "backdoor.econml.dml.DML". CausalML estimators can also be called. See `this demo notebook <https://py-why.github.io/dowhy/example_notebooks/dowhy-conditional-treatment-effects.html>`_.
 
 
         :param identified_estimand: a probability expression
@@ -229,9 +234,8 @@ class CausalModel:
         :param target_units: (Experimental) The units for which the treatment effect should be estimated. This can be of three types. (1) a string for common specifications of target units (namely, "ate", "att" and "atc"), (2) a lambda function that can be used as an index for the data (pandas DataFrame), or (3) a new DataFrame that contains values of the effect_modifiers and effect will be estimated only for this new data.
         :param effect_modifiers: Names of effect modifier variables can be (optionally) specified here too, since they do not affect identification. If None, the effect_modifiers from the CausalModel are used.
         :param fit_estimator: Boolean flag on whether to fit the estimator.
-        Setting it to False is useful to estimate the effect on new data using a previously fitted estimator.
+            Setting it to False is useful to estimate the effect on new data using a previously fitted estimator.
         :param method_params: Dictionary containing any method-specific parameters. These are passed directly to the estimating method. See the docs for each estimation method for allowed method-specific params.
-
         :returns: An instance of the CausalEstimate class, containing the causal effect estimate
             and other method-dependent information
 
@@ -260,12 +264,13 @@ class CausalModel:
                     causal_estimator_class = causal_estimators.get_class_object(estimator_method + "_estimator")
                 else:
                     third_party_estimator_package = estimator_package
-                    causal_estimator_class = causal_estimators.get_class_object(third_party_estimator_package)
+                    causal_estimator_class = causal_estimators.get_class_object(third_party_estimator_package, estimator_name)
                     if method_params is None:
                         method_params = {}
                     # Define the third-party estimation method to be used
-                    method_params["_" + third_party_estimator_package + "_methodname"] = estimator_name
+                    method_params[third_party_estimator_package + "_methodname"] = estimator_name
             else: # For older dowhy methods
+                print(estimator_name)
                 # Process the dowhy estimators
                 causal_estimator_class = causal_estimators.get_class_object(estimator_name + "_estimator")
         if identified_estimand.no_directed_path:
@@ -283,6 +288,12 @@ class CausalModel:
                                   treatment_value=treatment_value)
         else:
             if fit_estimator:
+                if method_params is not None and (num_components <= 2 or estimator_package == 'dowhy'):
+                    extra_args = method_params.get("init_params", {})
+                else:
+                    extra_args = {}
+                if method_params is None:
+                    method_params = {}
                 self.causal_estimator = causal_estimator_class(
                     self._data,
                     identified_estimand,
@@ -294,7 +305,8 @@ class CausalModel:
                     confidence_intervals = confidence_intervals,
                     target_units = target_units,
                     effect_modifiers = effect_modifiers,
-                    params=method_params)
+                    **method_params,
+                    **extra_args)
             else:
                 # Estimator had been computed in a previous call
                 assert self.causal_estimator is not None
@@ -325,9 +337,11 @@ class CausalModel:
         :param identified_estimand: a probability expression
             that represents the effect to be estimated. Output of
             CausalModel.identify_effect method
-        :param method_name: any of the estimation method to be used. See docs for estimate_effect method for a list of supported estimation methods.
+        :param method_name: any of the estimation method to be used. See docs
+            for estimate_effect method for a list of supported estimation methods.
         :param fit_estimator: Boolean flag on whether to fit the estimator.
-        Setting it to False is useful to compute the do-operation on new data using a previously fitted estimator.
+            Setting it to False is useful to compute the do-operation on new
+            data using a previously fitted estimator.
         :param method_params: Dictionary containing any method-specific parameters. These are passed directly to the estimating method.
 
         :returns: an instance of the CausalEstimate class, containing the causal effect estimate
@@ -360,7 +374,7 @@ class CausalModel:
                     identified_estimand,
                     self._treatment, self._outcome,
                     test_significance=False,
-                    params=method_params
+                    **method_params
                 )
             else:
                 # Estimator had been computed in a previous call
@@ -451,4 +465,59 @@ class CausalModel:
             print(summary_text)
         return summary_text
 
+    def refute_graph(self, k= 1, independence_test = None ,  independence_constraints = None ):
+        """
+        Check if the dependencies in input graph matches with the dataset -
+        ( X ⫫ Y ) | Z
+        where X and Y are considered as singleton sets currently
+        Z can have multiple variables
+        :param k: number of covariates in set Z
+        :param independence_test: dictionary containing methods to test conditional independece in data
+        :param independence_constraints: list of implications to be test input by the user in the format
+            [(x,y,(z1,z2)),
+            (x,y, (z3,))
+            ]
+        : returns: an instance of GraphRefuter class
+        """
+        if independence_test is not None:
+            test_for_continuous = independence_test['test_for_continuous']
+            test_for_discrete = independence_test['test_for_discrete']
+            refuter = GraphRefuter(data = self._data, method_name_continuous= test_for_continuous, method_name_discrete = test_for_discrete)
+
+        else:
+            refuter = GraphRefuter(data = self._data)
+
+        if independence_constraints is None:
+            all_nodes=list(self._graph.get_all_nodes(include_unobserved=False))
+            num_nodes = len(all_nodes)
+            array_indices = list(range(0,num_nodes))
+            all_possible_combinations = list(combinations(array_indices, 2))  #Generating sets of indices of size 2 for different x and y
+            conditional_independences=[]
+            self.logger.info("The followed conditional independences are true for the input graph")
+            for combination in all_possible_combinations:  #Iterate over the unique 2-sized sets [x,y]
+                i=combination[0]
+                j=combination[1]
+                a=all_nodes[i]
+                b=all_nodes[j]
+                if(i < j ):
+                    temp_arr = all_nodes[:i] + all_nodes[i+1:j]+ all_nodes[j+1:]
+                else:
+                    temp_arr = all_nodes[:j] + all_nodes[j+1:i]+ all_nodes[i+1:]
+                k_sized_lists=list(combinations(temp_arr,k))
+                for k_list in k_sized_lists:
+                    if self._graph.check_dseparation([str(a)], [str(b)], k_list) == True :
+                        self.logger.info(" %s and %s are CI given %s ", a, b, k_list)
+                        conditional_independences.append([a, b, k_list])
+
+            independence_constraints = conditional_independences
+
+        res = refuter.refute_model(independence_constraints = independence_constraints)
+
+        self.logger.info(refuter._refutation_passed)
+
+        return res
+
+
+
+
 
