@@ -11,6 +11,8 @@ from sklearn.linear_model import LogisticRegression
 from dowhy.causal_refuter import CausalRefutation
 from dowhy.causal_refuter import CausalRefuter
 from dowhy.causal_estimator import CausalEstimator
+from dowhy.causal_refuters.linear_sensitivity_analyzer import LinearSensitivityAnalyzer
+from dowhy.causal_estimators.linear_regression_estimator import LinearRegressionEstimator
 
 class AddUnobservedCommonCause(CausalRefuter):
 
@@ -42,6 +44,15 @@ class AddUnobservedCommonCause(CausalRefuter):
         :param effect_fraction_on_treatment: float: If effect_strength_on_treatment is not provided, this parameter decides the effect strength of the simulated confounder as a fraction of the effect strength of observed confounders on treatment. Defaults to 1.
         :param effect_fraction_on_outcome: float: If effect_strength_on_outcome is not provided, this parameter decides the effect strength of the simulated confounder as a fraction of the effect strength of observed confounders on outcome. Defaults to 1.
         :param plotmethod: string: Type of plot to be shown. If None, no plot is generated. This parameter is used only only when more than one treatment confounder effect values or outcome confounder effect values are provided. Default is "colormesh". Supported values are "contour", "colormesh" when more than one value is provided for both confounder effect value parameters; "line" when provided for only one of them.
+        :param simulated_method_name: method type to add unobserved common cause. "linear-partial-R2" for linear sensitivity analysis
+        :param percent_change_estimate: It is the percentage of reduction of treatment estimate that could alter the results (default = 1)
+                                        if percent_change_estimate = 1, the robustness value describes the strength of association of confounders with treatment and outcome in order to reduce the estimate by 100% i.e bring it down to 0.
+        :param confounder_increases_estimate: True implies that confounder increases the absolute value of estimate and vice versa. (Default = False)
+        :param benchmark_common_causes: names of variables for bounding strength of confounders
+        :param significance_level: confidence interval for statistical inference(default = 0.05)
+        :param null_hypothesis_effect: assumed effect under the null hypothesis
+        :param plot_estimate: Generate contour plot for estimate while performing sensitivity analysis. (default = True). 
+                              To override the setting, set plot_estimate = False.
         """
         super().__init__(*args, **kwargs)
 
@@ -53,6 +64,12 @@ class AddUnobservedCommonCause(CausalRefuter):
         self.frac_strength_outcome = kwargs["effect_fraction_on_outcome"] if "effect_fraction_on_outcome" in kwargs else 1
         self.simulated_method_name = kwargs["simulated_method_name"] if "simulated_method_name" in kwargs else "linear_based"
         self.plotmethod = kwargs['plotmethod'] if "plotmethod" in kwargs else "colormesh"
+        self.percent_change_estimate = kwargs["percent_change_estimate"] if 'percent_change_estimate' in kwargs else 1.0
+        self.significance_level = kwargs["significance_level"] if "significance_level" in kwargs else 0.05
+        self.confounder_increases_estimate = kwargs["confounder_increases_estimate"] if "confounder_increases_estimate" in kwargs else False
+        self.benchmark_common_causes = kwargs["benchmark_common_causes"] if "benchmark_common_causes" in kwargs else None
+        self.null_hypothesis_effect = kwargs["null_hypothesis_effect"] if "null_hypothesis_effect" in kwargs else 0
+        self.plot_estimate = kwargs["plot_estimate"] if "plot_estimate" in kwargs else True
         self.logger = logging.getLogger(__name__)
 
 
@@ -170,6 +187,23 @@ class AddUnobservedCommonCause(CausalRefuter):
 
         :return: CausalRefuter: An object that contains the estimated effect and a new effect and the name of the refutation used.
         """
+        if self.simulated_method_name == "linear-partial-R2":
+            if not(isinstance(self._estimate.estimator, LinearRegressionEstimator)):
+                raise NotImplementedError("Currently only LinearRegressionEstimator is supported for Sensitivity Analysis")
+
+            if(len(self._estimate.estimator._effect_modifier_names) > 0):
+                raise NotImplementedError("The current implementation does not support effect modifiers")
+
+            if(self.frac_strength_outcome == 1):
+                self.frac_strength_outcome = self.frac_strength_treatment
+
+            analyzer = LinearSensitivityAnalyzer(estimator = self._estimate.estimator,
+            data = self._data, treatment_name = self._treatment_name, 
+            percent_change_estimate = self.percent_change_estimate, significance_level = self.significance_level, benchmark_common_causes= self.benchmark_common_causes, null_hypothesis_effect = self.null_hypothesis_effect,
+            frac_strength_treatment = self.frac_strength_treatment, frac_strength_outcome = self.frac_strength_outcome, common_causes_order = self._estimate.estimator._observed_common_causes.columns)
+            
+            analyzer.check_sensitivity(plot = self.plot_estimate)
+            return analyzer
         if self.kappa_t is None:
             self.kappa_t = self.infer_default_kappa_t()
         if self.kappa_y is None:
@@ -370,32 +404,33 @@ class AddUnobservedCommonCause(CausalRefuter):
     def include_simulated_confounder(self, convergence_threshold = 0.1, c_star_max = 1000):
         '''
         This function simulates an unobserved confounder based on the data using the following steps:
-            1. It calculates the "residuals"  from the treatment and outcome model
-                i.) The outcome model has outcome as the dependent variable and all the observed variables including treatment as independent variables
-                ii.) The treatment model has treatment as the dependent variable and all the observed variables as independent variables.
+        1. It calculates the "residuals"  from the treatment and outcome model
+        i.) The outcome model has outcome as the dependent variable and all the observed variables including treatment as independent variables
+        ii.) The treatment model has treatment as the dependent variable and all the observed variables as independent variables.
 
-            2. U is an intermediate random variable drawn from the normal distribution with the weighted average of residuals as mean and a unit variance
-               U ~ N(c1*d_y + c2*d_t, 1)
-               where
-                *d_y and d_t are residuals from the treatment and outcome model
-                *c1 and c2 are coefficients to the residuals
+        2. U is an intermediate random variable drawn from the normal distribution with the weighted average of residuals as mean and a unit variance
+        U ~ N(c1*d_y + c2*d_t, 1)
+        where
+        *d_y and d_t are residuals from the treatment and outcome model
+        *c1 and c2 are coefficients to the residuals
 
-            3. The final U, which is the simulated unobserved confounder is obtained by debiasing the intermediate variable U by residualising it with X
+        3. The final U, which is the simulated unobserved confounder is obtained by debiasing the intermediate variable U by residualising it with X
 
 
         Choosing the coefficients c1 and c2:
         The coefficients are chosen based on these basic assumptions:
-            1. There is a hyperbolic relationship satisfying c1*c2 = c_star
-            2. c_star is chosen from a range of possible values based on the correlation of the obtained simulated variable with outcome and treatment.
-            3. The product of correlations with treatment and outcome should be at a minimum distance to the maximum correlations with treatment and outcome in any of the observed confounders
-            4. The ratio of the weights should be such that they maintain the ratio of the maximum possible observed coefficients within some confidence interval
+        1. There is a hyperbolic relationship satisfying c1*c2 = c_star
+        2. c_star is chosen from a range of possible values based on the correlation of the obtained simulated variable with outcome and treatment.
+        3. The product of correlations with treatment and outcome should be at a minimum distance to the maximum correlations with treatment and outcome in any of the observed confounders
+        4. The ratio of the weights should be such that they maintain the ratio of the maximum possible observed coefficients within some confidence interval
 
         :param c_star_max: The maximum possible value for the hyperbolic curve on which the coefficients to the residuals lie. It defaults to 1000 in the code if not specified by the user.
-        :type int
+            :type int
         :param convergence_threshold: The threshold to check the plateauing of the correlation while selecting a c_star. It defaults to 0.1 in the code if not specified by the user
-        :type float
-        :returns final_U: The simulated values of the unobserved confounder based on the data
-        :type pandas.core.series.Series
+            :type float
+
+        :returns: The simulated values of the unobserved confounder based on the data
+            :type pandas.core.series.Series
 
         '''
 
@@ -548,7 +583,7 @@ class AddUnobservedCommonCause(CausalRefuter):
     def generate_confounder_from_residuals(self, c1, c2, d_y, d_t, X):
         '''
         This function takes the residuals from the treatment and outcome model and their coefficients and simulates the intermediate random variable U by taking
-        the row wise normal distribution corresponding to each residual value and then debiasing the intermediate variable to get the final variable
+        the row wise normal distribution corresponding to each residual value and then debiasing the intermediate variable to get the final variable.
 
         :param c1: coefficient to the residual from the outcome model
         :type float
@@ -559,7 +594,7 @@ class AddUnobservedCommonCause(CausalRefuter):
         :param d_t: residuals from the treatment model
         :type list
 
-        :returns final_U: The simulated values of the unobserved confounder based on the data
+        :returns: The simulated values of the unobserved confounder based on the data
         :type pandas.core.series.Series
 
         '''
