@@ -6,15 +6,26 @@ import math
 
 import numpy as np
 import pandas as pd
-from numpy.random import choice
+from numpy.random import choice, random
+import networkx as nx
+import scipy.stats as ss
+import string
+from dowhy.utils.graph_operations import is_connected,convert_to_undirected_graph, get_random_node_pair, find_predecessor, del_edge, add_edge, get_simple_ordered_tree
+
 
 def sigmoid(x):
     return 1 / (1 + math.exp(-x))
 
-
-def stochastically_convert_to_binary(x):
+def convert_to_binary(x, stochastic=True):
     p = sigmoid(x)
-    return choice([0, 1], 1, p=[1-p, p])
+    if stochastic:
+        return choice([0, 1], 1, p=[1-p, p])
+    else:
+        return int(p > 0.5)
+
+def stochastically_convert_to_three_level_categorical(x):
+    p = sigmoid(x)
+    return choice([0, 1, 2], 1, p=[0.8*(1-p), 0.8*p, 0.2])
 
 def convert_to_categorical(arr, num_vars, num_discrete_vars,
         quantiles = [0.25, 0.5, 0.75], one_hot_encode=False):
@@ -52,12 +63,16 @@ def linear_dataset(beta, num_common_causes, num_samples, num_instruments=0,
                    num_treatments = 1,
                    num_frontdoor_variables=0,
                    treatment_is_binary=True,
+                   treatment_is_category=False,
                    outcome_is_binary=False,
+                   stochastic_discretization=True,
                    num_discrete_common_causes=0,
                    num_discrete_instruments=0,
                    num_discrete_effect_modifiers=0,
                    stddev_treatment_noise = 1,
+                   stddev_outcome_noise = 0.01,
                    one_hot_encode = False):
+    assert not (treatment_is_binary and treatment_is_category)
     W, X, Z, FD, c1, c2, ce, cz, cfd1, cfd2 = [None]*10
     W_with_dummy, X_with_categorical  = (None, None)
     beta = float(beta)
@@ -108,7 +123,9 @@ def linear_dataset(beta, num_common_causes, num_samples, num_instruments=0,
         t += Z @ cz
     # Converting treatment to binary if required
     if treatment_is_binary:
-        t = np.vectorize(stochastically_convert_to_binary)(t)
+        t = np.vectorize(convert_to_binary)(t)
+    elif treatment_is_category:
+        t = np.vectorize(stochastically_convert_to_three_level_categorical)(t)
 
     # Generating frontdoor variables if asked for
     if num_frontdoor_variables > 0:
@@ -125,21 +142,26 @@ def linear_dataset(beta, num_common_causes, num_samples, num_instruments=0,
                     (W_with_dummy.shape[1], num_frontdoor_variables))
             FD += W_with_dummy @ c1_frontdoor
 
-    def _compute_y(t, W, X, FD, beta, c2, ce, cfd2):
-        y = np.random.normal(0,0.01, num_samples)
+    def _compute_y(t, W, X, FD, beta, c2, ce, cfd2, stddev_outcome_noise):
+        y = np.random.normal(0,stddev_outcome_noise, num_samples)
         if num_frontdoor_variables > 0:
             y += FD @ cfd2
         else:
+            # NOTE: We are assuming a linear relationship *even when t is categorical* and integer coded.
+            # For categorical t, this example dataset has the effect size for category 2 being exactly
+            # double the effect for category 1
+            # This could be changed at this stage by one-hot encoding t and using a custom beta that
+            # sets a different effect for each category {0, 1, 2}
             y += t @ beta
         if num_common_causes > 0:
             y += W @ c2
         if num_effect_modifiers > 0:
             y += (X @ ce) * np.prod(t, axis=1)
         if outcome_is_binary:
-            y = np.vectorize(stochastically_convert_to_binary)(y)
+            y = np.vectorize(convert_to_binary)(y,stochastic_discretization)
         return y
 
-    y = _compute_y(t, W_with_dummy, X_with_categorical, FD, beta, c2, ce, cfd2)
+    y = _compute_y(t, W_with_dummy, X_with_categorical, FD, beta, c2, ce, cfd2, stddev_outcome_noise)
 
     data = np.column_stack((t, y))
     if num_common_causes > 0:
@@ -159,8 +181,8 @@ def linear_dataset(beta, num_common_causes, num_samples, num_instruments=0,
         FD_T1 = FD_noise + (T1 @ cfd1)
         FD_T0 = FD_noise + (T0 @ cfd1)
     ate = np.mean(
-            _compute_y(T1, W_with_dummy, X_with_categorical, FD_T1, beta, c2, ce, cfd2) -
-            _compute_y(T0, W_with_dummy, X_with_categorical, FD_T0, beta, c2, ce, cfd2))
+            _compute_y(T1, W_with_dummy, X_with_categorical, FD_T1, beta, c2, ce, cfd2, stddev_outcome_noise) -
+            _compute_y(T0, W_with_dummy, X_with_categorical, FD_T0, beta, c2, ce, cfd2, stddev_outcome_noise))
 
     treatments = [("v" + str(i)) for i in range(0, num_treatments)]
     outcome = "y"
@@ -177,7 +199,9 @@ def linear_dataset(beta, num_common_causes, num_samples, num_instruments=0,
     data = pd.DataFrame(data, columns=col_names)
     # Specifying the correct dtypes
     if treatment_is_binary:
-        data = data.astype({tname:'bool' for tname in treatments}, copy=False)
+        data = data.astype({tname: "bool" for tname in treatments}, copy=False)
+    elif treatment_is_category:
+        data = data.astype({tname: "category" for tname in treatments}, copy=False)
     if outcome_is_binary:
         data = data.astype({outcome: 'bool'}, copy=False)
     if num_discrete_common_causes >0 and not one_hot_encode:
@@ -228,7 +252,7 @@ def simple_iv_dataset(beta, num_samples,
     Z = np.random.normal(0, 1, (num_samples, num_instruments))
     t = np.random.normal(0, 1, (num_samples, num_treatments)) + Z @ cz + W @ c1
     if treatment_is_binary:
-        t = np.vectorize(stochastically_convert_to_binary)(t)
+        t = np.vectorize(convert_to_binary)(t)
 
     def _compute_y(t, W, beta, c2):
         y = t @ beta + W @ c2
@@ -381,3 +405,142 @@ def xy_dataset(num_samples, effect=True,
         "ate": None,
     }
     return ret_dict
+
+def create_discrete_column(num_samples,std_dev=1):
+    #Generating a random normal distribution of integers
+    x = np.arange(-5,6)
+    xU, xL = x + 0.5, x - 0.5 
+    prob = ss.norm.cdf(xU, scale = std_dev) - ss.norm.cdf(xL, scale = std_dev)  #probability of selecting a number x is p(x-0.5 < x < x+0.5) where x is a normal random variable with mean 0 and standard deviation std_dev
+    prob = prob / prob.sum() # normalize the probabilities so their sum is 1
+    nums = choice(a = x, size = num_samples, p = prob) #pick up an element 
+    return nums
+
+def convert_continuous_to_discrete(arr):
+    return arr.astype(int)
+
+
+def generate_random_graph(n, max_iter = 10):
+    """
+    Function to generate random Directed Acyclic Graph
+    :param n: number of nodes in the graph
+    :param max_iter: number of iterations to create graph
+
+    :returns: Directed Acyclic Graph
+    See: https://datascience.oneoffcoder.com/generate-random-bbn.html 
+    """
+    g = get_simple_ordered_tree(n)
+    for it in range(max_iter):
+        i, j = get_random_node_pair(n)
+        if g.has_edge(i, j) is True:
+            del_edge(i, j, g)
+        else:
+            add_edge(i, j, g)
+    return g
+
+
+
+def dataset_from_random_graph(num_vars, num_samples=1000, prob_edge=0.3, random_seed=100, prob_type_of_data = (0.333, 0.333, 0.334)):
+    """
+    This function generates a dataset with discrete and continuous kinds of variables.
+    It creates a random graph and models the variables linearly according to the relations in the graph.
+
+    :param num_vars: Number of variables in the dataset
+    :param num_samples: Number of samples in the dataset
+    :param prob_edge : Probability of an edge between two random nodes in a graph
+    :param random_seed: Seed for generating random graph
+    :param prob_type_of_data : 3-element tuple containing the probability of data being discrete, binary and continuous respectively.
+    :returns ret_dict : dictionary with information like dataframe, outcome, treatment, graph string and continuous, discrete and binary columns
+    """
+    assert (sum(list(prob_type_of_data)) == 1.0) 
+    np.random.seed(100) 
+    DAG = generate_random_graph(n = num_vars)
+    mapping = dict(zip(DAG, string.ascii_lowercase))
+    DAG = nx.relabel_nodes(DAG, mapping)
+    all_nodes = list(DAG.nodes)
+    all_nodes.sort()
+    num_nodes = len(all_nodes)
+    changed = dict()
+    discrete_cols = []
+    continuous_cols = []
+    binary_cols = []
+    random_numbers_array = np.random.rand(num_nodes) #Random numbers between 0 to 1 to decide if that particular node will be discrete or continuous
+
+    for node in all_nodes:
+        changed[node] = False
+    df = pd.DataFrame()
+    currset = list()
+    counter = 0
+
+    #Generating data for nodes which have no incoming edges
+    for node in all_nodes:
+        if DAG.in_degree(node) == 0:
+            x = random_numbers_array[counter]  
+            counter+=1
+            if x<=prob_type_of_data[0]:
+                df[node] = create_discrete_column(num_samples) #Generating discrete data
+                discrete_cols.append(node)
+            elif x<=prob_type_of_data[0]+prob_type_of_data[1]:
+                df[node] = np.random.normal(0,1,num_samples) #Generating continuous data
+                continuous_cols.append(node)
+            else:
+                nums = np.random.normal(0,1,num_samples)
+                df[node] = np.vectorize(convert_to_binary)(nums) #Generating binary data
+                discrete_cols.append(node)
+                binary_cols.append(node)
+            successors = list(DAG.successors(node)) #Storing immediate successors for next level data generation
+            successors.sort()
+            currset.extend(successors)
+            changed[node] = True 
+
+    #"currset" variable currently has all the successors of the nodes which had no incoming edges
+    while len(currset) > 0:
+        cs = list() #Variable to store immediate children of nodes present in "currset"
+        for node in currset: 
+            predecessors = list(DAG.predecessors(node))  #Getting all the parent nodes on which current "node" depends on
+            if changed[node] == False and all(changed[x] == True for x in predecessors): #Check if current "node" has not been processed yet and if all the parent nodes have been processed
+                successors = list(DAG.successors(node))
+                successors.sort()
+                cs.extend(successors) #Storing immediate children for next level data generation
+                X = df[predecessors].to_numpy() #Using parent nodes data 
+                c = np.random.uniform(0,1,len(predecessors)) 
+                t = np.random.normal(0,1, num_samples)+ X@c #Using Linear Regression to generate data
+                changed[node] = True
+                x = random_numbers_array[counter]
+                counter+=1
+                if x<=prob_type_of_data[0]:
+                    df[node] = convert_continuous_to_discrete(t)
+                    discrete_cols.append(node)
+                elif x<=prob_type_of_data[0]+prob_type_of_data[1]:
+                    df[node] = t
+                    continuous_cols.append(node)
+                else:
+                    nums = np.random.normal(0,1,num_samples)
+                    df[node] = np.vectorize(convert_to_binary)(nums)
+                    discrete_cols.append(node)
+                    binary_cols.append(node)
+        currset = cs 
+
+    outcome  = None  
+    for node in all_nodes:
+        if DAG.out_degree(node) == 0:
+            outcome = node #Node which has no successors is outcome
+            break
+
+    treatments = list()
+    for node in all_nodes:
+        if DAG.in_degree(node) > 0:
+            children = list(DAG.successors(node))
+            if outcome in children:
+                treatments.append(node) #Node which causes outcome is treatment
+   
+    gml_str = ("\n".join(nx.generate_gml(DAG)))
+    ret_dict = {
+        "df": df,
+        "outcome_name": outcome,
+        "treatment_name": treatments,
+        "gml_graph": gml_str,
+        "discrete_columns": discrete_cols,
+        "continuous_columns": continuous_cols,
+        "binary_columns": binary_cols
+    }
+    return ret_dict
