@@ -4,14 +4,13 @@ def query_yes_no(question, default=True):
     Source: https://stackoverflow.com/questions/3041986/apt-command-line-interface-like-yes-no-input
 
     If invalid input is given, the user will be asked until they actually give valid input.
-    Args:
-        question(str):  A question that is presented to the user.
-        default(bool|None): The default value when enter is pressed with no value.
+
+    Side Effects: Blocks program execution until valid input(y/n) is given.
+
+    :param question(str):  A question that is presented to the user.
+    :param default(bool|None): The default value when enter is pressed with no value.
         When None, there is no default value and the query will loop.
-    Returns:
-        A bool indicating whether user has entered yes or no.
-    Side Effects:
-        Blocks program execution until valid input(y/n) is given.
+    :returns: A bool indicating whether user has entered yes or no.
     """
     yes_list = ["yes", "y"]
     no_list = ["no", "n"]
